==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/NodeFactory__5fc__241.h <==
// class polyglot.ext.jl.ast.NodeFactory_c$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a61c65061722700c polyglot_ext_jl_ast_AbstractExtFactory__5fc
// @dep_class e194b50a0aad682e polyglot_ext_jl_ast_NodeFactory__5fc__241

// header file dependencies
// @dep_header polyglot_ext_jl_ast_AbstractExtFactory__5fc

#include "polyglot/ext/jl/ast/AbstractExtFactory__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_NodeFactory__5fc__241_H_
#define _JC_polyglot_ext_jl_ast_NodeFactory__5fc__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object;

typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object *);

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_AbstractExtFactory__5fc$vmethods	polyglot_ext_jl_ast_AbstractExtFactory__5fc;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods	polyglot_ext_jl_ast_NodeFactory__5fc__241;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs {
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs	polyglot_ext_jl_ast_NodeFactory__5fc__241;
    _jc_polyglot_ext_jl_ast_AbstractExtFactory__5fc$sub_refs	polyglot_ext_jl_ast_AbstractExtFactory__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_AbstractExtFactory__5fc$sub_nonrefs	polyglot_ext_jl_ast_AbstractExtFactory__5fc;
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs	polyglot_ext_jl_ast_NodeFactory__5fc__241;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object {
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_NodeFactory__5fc__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_NodeFactory__5fc__241_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/NodeFactory__5fc__241.h <==
// class polyglot.ext.jl.ast.NodeFactory_c$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a61c65061722700c polyglot_ext_jl_ast_AbstractExtFactory__5fc
// @dep_class e194b50a0aad682e polyglot_ext_jl_ast_NodeFactory__5fc__241

// header file dependencies
// @dep_header polyglot_ext_jl_ast_AbstractExtFactory__5fc

#include "polyglot/ext/jl/ast/AbstractExtFactory__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_NodeFactory__5fc__241_H_
#define _JC_polyglot_ext_jl_ast_NodeFactory__5fc__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object;

typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods {
};

// Vtable
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_AbstractExtFactory__5fc$vmethods	polyglot_ext_jl_ast_AbstractExtFactory__5fc;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vmethods	polyglot_ext_jl_ast_NodeFactory__5fc__241;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs {
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_refs	polyglot_ext_jl_ast_NodeFactory__5fc__241;
    _jc_polyglot_ext_jl_ast_AbstractExtFactory__5fc$sub_refs	polyglot_ext_jl_ast_AbstractExtFactory__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_AbstractExtFactory__5fc$sub_nonrefs	polyglot_ext_jl_ast_AbstractExtFactory__5fc;
    _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$sub_nonrefs	polyglot_ext_jl_ast_NodeFactory__5fc__241;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$object {
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$vtype _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_NodeFactory__5fc__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_NodeFactory__5fc__241$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_NodeFactory__5fc__241_H_ */
